@@ -1,4 +1,4 @@
-# Copyright 2008-2020  Sutou Kouhei <kou@cozmixng.org>
+# Copyright 2008-2021  Sutou Kouhei <kou@cozmixng.org>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,12 @@ require "rbconfig"
 require "shellwords"
 
 class PackageConfig
+  class Error < StandardError
+  end
+
+  class NotFoundError < Error
+  end
+
   SEPARATOR = File::PATH_SEPARATOR
 
   class << self
@@ -295,7 +301,7 @@ class PackageConfig
   end
 
   def normalize_path_flags(path_flags, flag_option)
-    return path_flags unless /-mingw32\z/ === RUBY_PLATFORM
+    return path_flags unless /-mingw(?:32|-ucrt)\z/ === RUBY_PLATFORM
 
     pkg_config_prefix = self.class.native_pkg_config_prefix
     return path_flags unless pkg_config_prefix
@@ -380,7 +386,7 @@ class PackageConfig
 
   IDENTIFIER_RE = /[a-zA-Z\d_\.]+/
   def parse_pc
-    raise ".pc for #{@name} doesn't exist." unless exist?
+    raise NotFoundError, ".pc doesn't exist: <#{@name}>" unless exist?
     @variables = {}
     @declarations = {}
     File.open(pc_path) do |input|
@@ -439,6 +445,11 @@ class PackageConfig
       "/opt/X11/lib/pkgconfig",
       "/usr/share/pkgconfig",
     ]
+    if Object.const_defined?(:RubyInstaller)
+      mingw_bin_path = RubyInstaller::Runtime.msys2_installation.mingw_bin_path
+      mingw_pkgconfig_path = Pathname.new(mingw_bin_path) + "../lib/pkgconfig"
+      default_paths.unshift(mingw_pkgconfig_path.cleanpath.to_s)
+    end
     libdir = ENV["PKG_CONFIG_LIBDIR"]
     default_paths.unshift(libdir) if libdir
 
@@ -452,6 +463,7 @@ class PackageConfig
       paths << (pkg_config_prefix + "libx32/pkgconfig").to_s
       paths << (pkg_config_prefix + "lib/pkgconfig").to_s
       paths << (pkg_config_prefix + "libdata/pkgconfig").to_s
+      paths << (pkg_config_prefix + "share/pkgconfig").to_s
     end
     if /-darwin\d[\d\.]*\z/ =~ RUBY_PLATFORM and
         /\A(\d+\.\d+)/ =~ `sw_vers -productVersion`
@@ -474,7 +486,11 @@ class PackageConfig
         homebrew_repository_candidates << Pathname(homebrew_repository)
       end
       homebrew_repository_candidates.uniq.each do |candidate|
-        path = candidate + "Library/Homebrew/os/mac/pkgconfig/#{mac_os_version}"
+        pkgconfig_base_path = candidate + "Library/Homebrew/os/mac/pkgconfig"
+        path = pkgconfig_base_path + mac_os_version
+        unless path.exist?
+          path = pkgconfig_base_path + mac_os_version.gsub(/\.\d+\z/, "")
+        end
         paths << path.to_s if path.exist?
       end
     end
